from flask import Blueprint
from flask_jwt_extended import jwt_required
from flask_restful import Resource, Api

from portal.rest import rest_helpers
from portal.rest.schemas import notification_schema, submission_result_schema
from portal.service import auth, permissions, general
from portal.service.errors import ForbiddenError
from portal.service.notifications import send_notification, send_submission_result_message
from portal.tools.decorators import error_handler

notifications_blueprint = Blueprint('notifications', __name__)
notifications_api = Api(notifications_blueprint)


class NotificationResource(Resource):
    @error_handler
    @jwt_required
    def post(self, notification_type):
        client = auth.find_client()

        if not (permissions.check_sysadmin(client) or
                permissions.check_component(component=client)):
            raise ForbiddenError(uid=client.id)

        data = rest_helpers.parse_request_data(
            notification_schema, action='update', resource='project'
            )

        send_notification(data, notification_type=notification_type)
        return {'message': 'Notification sent!'}, 200


class SubmissionResultResource(Resource):
    @error_handler
    @jwt_required
    def post(self, sid):
        client = auth.find_client()

        if not (permissions.check_sysadmin(client) or
                permissions.check_component(component=client)):
            raise ForbiddenError(uid=client.id)

        data = rest_helpers.parse_request_data(
            submission_result_schema, action='update', resource='project'
            )

        submission = general.find_submission(sid)
        send_submission_result_message(submission=submission, data=data)
        return {'message': 'Notification sent!'}, 200


notifications_api.add_resource(NotificationResource, '/<string:notification_type>')
notifications_api.add_resource(SubmissionResultResource, '/submission/<string:sid>')
