import gitlab
from flask import Flask


class GitlabFactory(object):
    """Gitlab client wrapper for flask
    DOC: http://python-gitlab.readthedocs.io/en/stable/api-usage.html
    """
    def __init__(self, app: Flask=None):
        """Creates instance of the Gitlab Client Factory
        Args:
            app(Flask): Flask application Optional argument
        """
        self.app: Flask = app

    def init_app(self, app: Flask):
        """Initializes the client with a flask application
        Args:
            app(Flask): Flask application
        """
        self.app = app

    def instance(self, *args, **kwargs) -> gitlab.Gitlab:
        """Creates instance of the Gitlab client
        Args:
            *args:
            **kwargs:

        Returns(gitlab.Gitlab): Gitlab client instance
        """
        return gitlab.Gitlab(self.app.config.get('GITLAB_URL'), *args, **kwargs)
